==> 0.0.1.tar.gz: ios/Classes/SwiftRexswiftFlutterPlugin.swift <==
import Flutter
import UIKit

public class SwiftRexswiftFlutterPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "rexswift_flutter", binaryMessenger: registrar.messenger())
    let instance = SwiftRexswiftFlutterPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

 func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {

      if "configure" == call.method {

          if call.arguments != nil && (call.arguments is [String : Any]) {
              let appId = call.arguments["appId"]
              let senderId = call.arguments["senderId"]
              let appGroup = call.arguments["appGroup"]
              let isDev = call.arguments["isDev"]
              print("appId:\(appId)")
              print("senderId:\(senderId)")
              print("isDev:\(isDev)")
              print("appGroup:\(appGroup)")
              QGSdk.getSharedInstance().onStart(appId, withAppGroup: appGroup, setDevProfile: isDev)
              result(nil)
              return
          }
          result(FlutterMethodNotImplemented)
      } else if "logEvent" == call.method {

          let parameters: [String : Any] = call.arguments["parameters"]
          print("parameters \(parameters)")

          let vts = call.arguments["vts"]
          print("vtc \(vts)")

          let vtsCurr = call.arguments["vtsCurr"]
          print("vtsCurr \(vtsCurr)")

          let eventName = call.arguments["eventName"]

          QGSdk.getSharedInstance().logEvent(eventName, withParameters: parameters, withValueToSum: vts, withValueToSumCurrency: vtsCurr)

          result(nil)
      } else {
          result(FlutterMethodNotImplemented)
      }
  }
}

==> 0.0.3.tar.gz: ios/Classes/SwiftRexswiftFlutterPlugin.swift <==
import Flutter
import UIKit
import Appier

public class SwiftRexswiftFlutterPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "rexswift_flutter", binaryMessenger: registrar.messenger())
    let instance = SwiftRexswiftFlutterPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

 func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {

      if "configure" == call.method {

          if call.arguments != nil && (call.arguments is [String : Any]) {
              let appId = call.arguments["appId"] as? String
              let senderId = call.arguments["senderId"] as? String
              let appGroup = call.arguments["appGroup"] as? String
              let isDev = call.arguments["isDev"] as? Bool
              print("appId:\(appId)")
              print("senderId:\(senderId)")
              print("isDev:\(isDev)")
              print("appGroup:\(appGroup)")
              QGSdk.getSharedInstance().onStart(appId, withAppGroup: appGroup, setDevProfile: isDev)
              result(nil)
              return
          }
          result(FlutterMethodNotImplemented)
      } else if "logEvent" == call.method {

          let parameters: [String : Any] = call.arguments["parameters"]
          print("parameters \(parameters)")

          let vts = call.arguments["vts"]
          print("vtc \(vts)")

          let vtsCurr = call.arguments["vtsCurr"]
          print("vtsCurr \(vtsCurr)")

          let eventName = call.arguments["eventName"]

          QGSdk.getSharedInstance().logEvent(eventName, withParameters: parameters, withValueToSum: vts, withValueToSumCurrency: vtsCurr)

          result(nil)
      } else {
          result(FlutterMethodNotImplemented)
      }
  }
}
